@@ -1,6 +1,6 @@
 """Rasterio's GDAL/AWS environment"""
 
-import attr
+from contextlib import ExitStack
 from functools import wraps, total_ordering
 from inspect import getfullargspec as getargspec
 import logging
@@ -9,11 +9,18 @@ import re
 import threading
 import warnings
 
+import attr
+
 from rasterio._env import (
-        GDALEnv, get_gdal_config, set_gdal_config,
-        GDALDataFinder, PROJDataFinder, set_proj_data_search_path)
-from rasterio.errors import (
-    EnvError, GDALVersionError, RasterioDeprecationWarning)
+    GDALEnv,
+    get_gdal_config,
+    set_gdal_config,
+    GDALDataFinder,
+    PROJDataFinder,
+    set_proj_data_search_path,
+)
+from rasterio._version import gdal_version
+from rasterio.errors import EnvError, GDALVersionError, RasterioDeprecationWarning
 from rasterio.session import Session, DummySession
 
 
@@ -52,7 +59,7 @@ local = ThreadEnv()
 log = logging.getLogger(__name__)
 
 
-class Env(object):
+class Env:
     """Abstraction for GDAL and AWS configuration
 
     The GDAL library is stateful: it has a registry of format drivers,
@@ -349,7 +356,7 @@ def delenv():
     local._env = None
 
 
-class NullContextManager(object):
+class NullContextManager:
 
     def __init__(self):
         pass
@@ -441,7 +448,7 @@ def ensure_env_with_credentials(f):
 
 @attr.s(slots=True)
 @total_ordering
-class GDALVersion(object):
+class GDALVersion:
     """Convenience class for obtaining GDAL major and minor version components
     and comparing between versions.  This is highly simplistic and assumes a
     very normal numbering scheme for versions and ignores everything except
@@ -497,7 +504,6 @@ class GDALVersion(object):
     @classmethod
     def runtime(cls):
         """Return GDALVersion of current GDAL runtime"""
-        from rasterio._base import gdal_version  # to avoid circular import
         return cls.parse(gdal_version())
 
     def at_least(self, other):
@@ -511,22 +517,27 @@ def require_gdal_version(version, param=None, values=None, is_max_version=False,
     by the runtime version of GDAL.  Raises GDALVersionError if conditions
     are not met.
 
-    Examples:
-    \b
+    Examples
+    --------
+
+    .. code-block:: python
+
         @require_gdal_version('2.2')
         def some_func():
 
     calling `some_func` with a runtime version of GDAL that is < 2.2 raises a
     GDALVersionErorr.
 
-    \b
+    .. code-block:: python
+
         @require_gdal_version('2.2', param='foo')
         def some_func(foo='bar'):
 
     calling `some_func` with parameter `foo` of any value on GDAL < 2.2 raises
     a GDALVersionError.
 
-    \b
+    .. code-block:: python
+
         @require_gdal_version('2.2', param='foo', values=('bar',))
         def some_func(foo=None):
 
@@ -626,7 +637,7 @@ if 'GDAL_DATA' not in os.environ:
         log.debug("GDAL data found in package: path=%r.", path)
         set_gdal_config("GDAL_DATA", path)
 
-    # See https://github.com/mapbox/rasterio/issues/1631.
+    # See https://github.com/rasterio/rasterio/issues/1631.
     elif GDALDataFinder().find_file("header.dxf"):
         log.debug("GDAL data files are available at built-in paths.")
 
@@ -637,7 +648,12 @@ if 'GDAL_DATA' not in os.environ:
             set_gdal_config("GDAL_DATA", path)
             log.debug("GDAL data found in other locations: path=%r.", path)
 
-if "PROJ_LIB" in os.environ:
+if "PROJ_DATA" in os.environ:
+    # PROJ 9.1+
+    path = os.environ["PROJ_DATA"]
+    set_proj_data_search_path(path)
+elif "PROJ_LIB" in os.environ:
+    # PROJ < 9.1
     path = os.environ["PROJ_LIB"]
     set_proj_data_search_path(path)
 
@@ -646,7 +662,7 @@ elif PROJDataFinder().search_wheel():
     log.debug("PROJ data found in package: path=%r.", path)
     set_proj_data_search_path(path)
 
-# See https://github.com/mapbox/rasterio/issues/1631.
+# See https://github.com/rasterio/rasterio/issues/1631.
 elif PROJDataFinder().has_data():
     log.debug("PROJ data files are available at built-in paths.")
 
