@@ -5,9 +5,8 @@ Most can handle a numpy array or `rasterio.Band()`.
 Primarily supports `$ rio insp`.
 """
 
-from __future__ import absolute_import
-
 from collections import OrderedDict
+from itertools import zip_longest
 import logging
 import warnings
 
@@ -16,7 +15,6 @@ import numpy as np
 import rasterio
 from rasterio.io import DatasetReader
 from rasterio.transform import guard_transform
-from rasterio.compat import zip_longest
 
 logger = logging.getLogger(__name__)
 
@@ -35,7 +33,7 @@ def get_plt():
 
 
 def show(source, with_bounds=True, contour=False, contour_label_kws=None,
-         ax=None, title=None, transform=None, adjust='linear', **kwargs):
+         ax=None, title=None, transform=None, adjust=False, **kwargs):
     """Display a raster or raster band using matplotlib.
 
     Parameters
@@ -59,18 +57,18 @@ def show(source, with_bounds=True, contour=False, contour_label_kws=None,
         Title for the figure.
     transform : Affine, optional
         Defines the affine transform if source is an array
-    adjust : 'linear' | None
+    adjust : bool
         If the plotted data is an RGB image, adjust the values of
         each band so that they fall between 0 and 1 before plotting. If
-        'linear', values will be adjusted by the min / max of each band. If
-        None, no adjustment will be applied.
+        True, values will be adjusted by the min / max of each band. If
+        False, no adjustment will be applied.
     **kwargs : key, value pairings optional
         These will be passed to the matplotlib imshow or contour method
         depending on contour argument.
         See full lists at:
-        http://matplotlib.org/api/axes_api.html?highlight=imshow#matplotlib.axes.Axes.imshow
+        https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.imshow.html
         or
-        http://matplotlib.org/api/axes_api.html?highlight=imshow#matplotlib.axes.Axes.contour
+        https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.contour.html
 
     Returns
     -------
@@ -120,7 +118,7 @@ def show(source, with_bounds=True, contour=False, contour_label_kws=None,
             arr = source
         if transform and with_bounds:
             kwargs['extent'] = plotting_extent(arr, transform)
-    if adjust is True and arr.ndim >= 3:
+    if adjust and arr.ndim >= 3:
         # Adjust each band by the min/max so it will plot as RGB.
         arr = reshape_as_raster(arr)
         for ii, band in enumerate(arr):
@@ -222,7 +220,7 @@ def reshape_as_raster(arr):
     return im
 
 
-def show_hist(source, bins=10, masked=True, title='Histogram', ax=None, **kwargs):
+def show_hist(source, bins=10, masked=True, title='Histogram', ax=None, label=None, **kwargs):
     """Easily display a histogram with matplotlib.
 
     Parameters
@@ -240,6 +238,9 @@ def show_hist(source, bins=10, masked=True, title='Histogram', ax=None, **kwargs
         Title for the figure.
     ax : matplotlib axes (opt)
         The raster will be added to this axes if passed.
+    label : matplotlib labels (opt)
+        If passed, matplotlib will use this label list.
+        Otherwise, a default label list will be automatically created
     **kwargs : optional keyword arguments
         These will be passed to the matplotlib hist method. See full list at:
         http://matplotlib.org/api/axes_api.html?highlight=imshow#matplotlib.axes.Axes.hist
@@ -257,7 +258,7 @@ def show_hist(source, bins=10, masked=True, title='Histogram', ax=None, **kwargs
     # so we need the overall min/max to constrain the plot
     rng = np.nanmin(arr), np.nanmax(arr)
 
-    if len(arr.shape) is 2:
+    if len(arr.shape) == 2:
         arr = np.expand_dims(arr.flatten(), 0).T
         colors = ['gold']
     else:
@@ -273,12 +274,17 @@ def show_hist(source, bins=10, masked=True, title='Histogram', ax=None, **kwargs
     else:
         colors = colors[:arr.shape[-1]]
 
-    # If a rasterio.Band() is given make sure the proper index is displayed
-    # in the legend.
-    if isinstance(source, (tuple, rasterio.Band)):
-        labels = [str(source[1])]
+    # if the user used the label argument, pass them drectly to matplotlib
+    if label:
+        labels = label
+    # else, create default labels
     else:
-        labels = (str(i + 1) for i in range(len(arr)))
+        # If a rasterio.Band() is given make sure the proper index is displayed
+        # in the legend.
+        if isinstance(source, (tuple, rasterio.Band)):
+            labels = [str(source[1])]
+        else:
+            labels = (str(i + 1) for i in range(len(arr)))
 
     if ax:
         show = False
